==> open-xchange-usm_6.18.0.0.orig.tar.gz: open-xchange-usm-6.18.0.0/com.openexchange.usm.syncml/src/com/openexchange/usm/syncml/config/SimpleFolderHierarchy.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.syncml.config;

import java.util.*;

import com.openexchange.usm.api.exceptions.USMException;
import com.openexchange.usm.api.session.*;

public class SimpleFolderHierarchy extends CompleteFolderHierarchy {

	@Override
	public Map<String, Folder> getFolders(Session usmSession) throws USMException {
		DataObject[] folders = usmSession.syncFoldersWithServer(Session.NO_LIMIT, null, false,
				ConflictResolution.USE_SERVER).getNewState();
		Folder f = getStandardContactsFolder(folders);
		if (f == null)
			return Collections.emptyMap();
		Map<String, Folder> data = new HashMap<String, Folder>();
		computeLocalURI(data, new HashMap<Folder, String>(), new HashMap<String, Folder>(), f);
		return data;
	}

	@Override
	public Folder getFolder(Map<String, Folder> map, String locURI) throws USMException {
		return map.size() > 0 ? map.values().iterator().next() : null;
	}
}

==> open-xchange-usm_6.20.8.0.orig.tar.gz: open-xchange-usm-6.20.8.0/com.openexchange.usm.syncml/src/com/openexchange/usm/syncml/config/SimpleFolderHierarchy.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.syncml.config;

import java.util.*;

import com.openexchange.usm.api.exceptions.USMException;
import com.openexchange.usm.api.session.*;

public class SimpleFolderHierarchy extends CompleteFolderHierarchy {

	@Override
	public Map<String, Folder> getFolders(Session usmSession) throws USMException {
		DataObject[] folders = usmSession.syncFoldersWithServer(Session.NO_LIMIT, null, false,
				ConflictResolution.USE_SERVER).getNewState();
		Folder f = getStandardContactsFolder(folders);
		if (f == null)
			return Collections.emptyMap();
		Map<String, Folder> data = new HashMap<String, Folder>();
		computeLocalURI(data, new HashMap<Folder, String>(), new HashMap<String, Folder>(), f);
		return data;
	}

	@Override
	public Folder getFolder(Map<String, Folder> map, String locURI) throws USMException {
		return (map.size() > 0) ? map.values().iterator().next() : null;
	}
}
